# CustomObjectDefinitionRelationshipRecordConstraints


## Properties

Name | Type | Description | Notes
------------ | ------------- | ------------- | -------------
**create** | [**CustomObjectDefinitionRelationshipRecordConstraintsCreate**](CustomObjectDefinitionRelationshipRecordConstraintsCreate.md) |  | [optional] 

## Example

```python
from zuora_sdk.models.custom_object_definition_relationship_record_constraints import CustomObjectDefinitionRelationshipRecordConstraints

# TODO update the JSON string below
json = "{}"
# create an instance of CustomObjectDefinitionRelationshipRecordConstraints from a JSON string
custom_object_definition_relationship_record_constraints_instance = CustomObjectDefinitionRelationshipRecordConstraints.from_json(json)
# print the JSON string representation of the object
print(CustomObjectDefinitionRelationshipRecordConstraints.to_json())

# convert the object into a dict
custom_object_definition_relationship_record_constraints_dict = custom_object_definition_relationship_record_constraints_instance.to_dict()
# create an instance of CustomObjectDefinitionRelationshipRecordConstraints from a dict
custom_object_definition_relationship_record_constraints_from_dict = CustomObjectDefinitionRelationshipRecordConstraints.from_dict(custom_object_definition_relationship_record_constraints_dict)
```
[[Back to Model list]](../README.md#documentation-for-models) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to README]](../README.md)


